-
Notifications
You must be signed in to change notification settings - Fork 516
VideoSubscriberAccount iOS xcode14.3 beta2
Alex Soto edited this page Mar 15, 2023
·
2 revisions
#VideoSubscriberAccount.framework https://github.com/xamarin/xamarin-macios/pull/17810
diff -ruN /Applications/Xcode_14.3.0-beta.app/Contents/Developer/Platforms/iPhoneOS.platform/Developer/SDKs/iPhoneOS.sdk/System/Library/Frameworks/VideoSubscriberAccount.framework/Headers/VSUserAccountManager.h /Applications/Xcode_14.3.0-beta2.app/Contents/Developer/Platforms/iPhoneOS.platform/Developer/SDKs/iPhoneOS.sdk/System/Library/Frameworks/VideoSubscriberAccount.framework/Headers/VSUserAccountManager.h
--- /Applications/Xcode_14.3.0-beta.app/Contents/Developer/Platforms/iPhoneOS.platform/Developer/SDKs/iPhoneOS.sdk/System/Library/Frameworks/VideoSubscriberAccount.framework/Headers/VSUserAccountManager.h 2023-02-12 14:15:11
+++ /Applications/Xcode_14.3.0-beta2.app/Contents/Developer/Platforms/iPhoneOS.platform/Developer/SDKs/iPhoneOS.sdk/System/Library/Frameworks/VideoSubscriberAccount.framework/Headers/VSUserAccountManager.h 2023-02-25 10:27:30
@@ -18,9 +18,9 @@
typedef NS_OPTIONS(NSInteger, VSUserAccountQueryOptions) {
VSUserAccountQueryNone = 0, // default
VSUserAccountQueryAllDevices // return VSUserAccounts also registered on other devices in the users iCloud account
-} NS_SWIFT_NAME(VSUserAccountManager.QueryOptions) API_AVAILABLE(ios(16.4), tvos(16.4)) API_UNAVAILABLE(macCatalyst);
+} NS_SWIFT_NAME(VSUserAccountManager.QueryOptions) API_AVAILABLE(ios(16.4), tvos(16.4), macos(13.3)) API_UNAVAILABLE(watchos, macCatalyst);
-VS_EXPORT API_AVAILABLE(ios(16.4), tvos(16.4)) API_UNAVAILABLE(macCatalyst)
+VS_EXPORT API_AVAILABLE(ios(16.4), tvos(16.4), macos(13.3)) API_UNAVAILABLE(watchos, macCatalyst)
@interface VSUserAccountManager : NSObject
@property (nonatomic, readonly, class) VSUserAccountManager *sharedUserAccountManager;
- README
- xcode13.0 Binding Status
- xcode13.1 Binding Status
- xcode13.2 Binding Status
- xcode13.3 Binding Status
- xcode13.4 Binding Status
- xcode14.0 Binding Status
- xcode14.1 Binding Status
- xcode14.2 Binding Status
- xcode14.3 Binding Status
- xcode15.0 Binding Status
- xcode15.1 Binding Status
- xcode15.3 Binding Status
- xcode15.4 Binding Status
- xcode16.0 Binding Status
- xcode16.1 Binding Status
- xcode16.2 Binding Status
diff -ruN /Applications/Xcode_14.3.0-beta.app/Contents/Developer/Platforms/iPhoneOS.platform/Developer/SDKs/iPhoneOS.sdk/System/Library/Frameworks/VideoSubscriberAccount.framework/Headers/VSUserAccount.h /Applications/Xcode_14.3.0-beta2.app/Contents/Developer/Platforms/iPhoneOS.platform/Developer/SDKs/iPhoneOS.sdk/System/Library/Frameworks/VideoSubscriberAccount.framework/Headers/VSUserAccount.h
--- /Applications/Xcode_14.3.0-beta.app/Contents/Developer/Platforms/iPhoneOS.platform/Developer/SDKs/iPhoneOS.sdk/System/Library/Frameworks/VideoSubscriberAccount.framework/Headers/VSUserAccount.h 2023-02-11 22:23:07
+++ /Applications/Xcode_14.3.0-beta2.app/Contents/Developer/Platforms/iPhoneOS.platform/Developer/SDKs/iPhoneOS.sdk/System/Library/Frameworks/VideoSubscriberAccount.framework/Headers/VSUserAccount.h 2023-02-25 10:24:21
@@ -15,14 +15,14 @@
typedef NS_ENUM(NSInteger, VSUserAccountType) {
VSUserAccountTypeFree, // Default. The user has access to free content only.
VSUserAccountTypePaid // The user has access to content offered to paid subscriptions.
-} NS_REFINED_FOR_SWIFT API_AVAILABLE(ios(16.4), tvos(16.4)) API_UNAVAILABLE(macCatalyst);
+} NS_REFINED_FOR_SWIFT API_AVAILABLE(ios(16.4), tvos(16.4), macos(13.3)) API_UNAVAILABLE(watchos, macCatalyst);
typedef NS_ENUM(NSInteger, VSOriginatingDeviceCategory) {
VSOriginatingDeviceCategoryMobile,
VSOriginatingDeviceCategoryOther
-} NS_REFINED_FOR_SWIFT API_AVAILABLE(ios(16.4), tvos(16.4)) API_UNAVAILABLE(macCatalyst);
+} NS_REFINED_FOR_SWIFT API_AVAILABLE(ios(16.4), tvos(16.4), macos(13.3)) API_UNAVAILABLE(watchos, macCatalyst);
-VS_EXPORT API_AVAILABLE(ios(16.4), tvos(16.4)) API_UNAVAILABLE(macCatalyst)
+VS_EXPORT API_AVAILABLE(ios(16.4), tvos(16.4), macos(13.3)) API_UNAVAILABLE(watchos, macCatalyst)
NS_REFINED_FOR_SWIFT
@interface VSUserAccount : NSObject
@@ -42,8 +42,8 @@
@property (nonatomic, assign) VSUserAccountType accountType;
-// Indicates if the user has deleted their account.
-@property (nonatomic, assign, getter=isDeleted) BOOL deleted;
+// Indicates if the user has signed out of their account.
+@property (nonatomic, assign, getter=isSignedOut) BOOL signedOut;
// The date in which the billing cycle ends for paid accounts.
// used as a heuristic to determine when a refresh should occur.